Address class

Constructors

Address()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

addAllItem ↔ bool
getter/setter pair
provinces ↔ List<String>
getter/setter pair

Static Methods

getCities(String province) → dynamic
getCityCodeByName({String? provinceName, String? cityName, String? townName}) → List<String>
根据城市名 找到城市编码 simple use List
getCityNameByCode({String? provinceCode, String? cityCode, String? townCode}) → List<String>
通过城市code 返回城市名 simple use List
getTowns(dynamic cityCode) → dynamic
spliceCityName({String? pname, String? cname, String? tname}) → String