DateTimeData class

时间选择器 item 生成的对应数据

Constructors

DateTimeData()

Properties

day ↔ List
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hour ↔ List
getter/setter pair
minute ↔ List
getter/setter pair
month ↔ List
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
second ↔ List
getter/setter pair
year ↔ List
getter/setter pair

Methods

getListByName(DateType type) → List
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited