Suffix class

后缀标签

Constructors

Suffix({String years = '', String month = '', String days = '', String hours = '', String minutes = '', String seconds = ''})
Suffix.normal()

Properties

days ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hours ↔ String
getter/setter pair
minutes ↔ String
getter/setter pair
month ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
seconds ↔ String
getter/setter pair
years ↔ String
getter/setter pair

Methods

getSingle(DateType dateType) → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited