PicketUtil class

工具类:提供常用的空值检查方法

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

listEmpty(List? list) → bool
判断 List 为空
listNoEmpty(List? list) → bool
判断 List 不为空(修复了原来的逻辑错误)
mapEmpty(Map? value) → bool
Map 为空
mapNoEmpty(Map? value) → bool
Map 不为空
strEmpty(String? value) → bool
字符串为空
strNoEmpty(String? value) → bool
字符串不为空